require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/os/env/process/process_message'

module UU
  module OS
    module Env
      module Process

        # Parameters of event sent by process.
        class ProcessEvent < UU::OS::REST::DTO

          # Type of event. Allowed values {UU::OS::Env::Process::ProcessEventType}.
          # @param [String]
          # @return [String]
          attr_accessor :event_type;

          # Code of event.
          # @param [String]
          # @return [String]
          attr_accessor :event_code;

          # Event message.
          # @param [String]
          # @return [String]
          attr_accessor :event_message;

          # URI of object related to this event.
          # @param [String, UU::OS::UESURI]
          # @return [UU::OS::UESURI]
          attr_accessor :related_object;

          # Optional exception.
          # @param [Exception]
          # @return [Exception]
          attr_accessor :exception;

          def event_type
            attributes[:eventType]
          end

          def event_type=(val)
            attributes[:eventType] = val
          end

          def event_code
            attributes[:eventCode]
          end

          def event_code=(val)
            attributes[:eventCode] = val
          end

          def event_message
            attributes[:eventMessage]
          end

          def event_message=(val)
            if val
              attributes[:eventMessage] = UU::OS::Env::Process::ProcessMessage.new(val)
            else
              attributes[:eventMessage] = nil
            end
          end

          def related_object
            attributes[:relatedObject]
          end

          def related_object=(val)
            if val
              attributes[:relatedObject] = UU::OS::UESURI.new(val)
            else
              attributes[:relatedObject] = nil
            end
          end

          def exception
            attributes[:exception]
          end

          def exception=(val)
            attributes[:exception] = val
          end

        end

      end
    end
  end
end
